Crate kcr_agent_k8s_elastic_co

Crate kcr_agent_k8s_elastic_co 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the agent.k8s.elastic.co group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

agent.k8s.elastic.co/v1alpha1

  • Agent

Modules

v1alpha1